"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_select_event_1 = __importDefault(require("react-select-event"));
const user_event_1 = __importDefault(require("@testing-library/user-event"));
const react_2 = require("@testing-library/react");
const ConfigurablePager_1 = require("./ConfigurablePager");
const __testHelpers__1 = require("../__testHelpers__");
describe('ConfigurablePager', () => {
    it('lets you change the page size', async () => {
        const onChange = jest.fn();
        (0, react_2.render)(react_1.default.createElement(ConfigurablePager_1.ConfigurablePager, { page: 1, pageSize: 10, totalPages: 10, pageSizes: [10, 13, 17], onChange: onChange }));
        await (0, react_2.act)(async () => {
            await react_select_event_1.default.select(react_2.screen.getByLabelText('Items per page'), '13');
            await (0, __testHelpers__1.waitForReactUpdates)();
        });
        expect(onChange).toHaveBeenCalled();
        expect(onChange).toHaveBeenCalledWith(1, 13);
    });
    it('lets you change the page', async () => {
        const onChange = jest.fn();
        (0, react_2.render)(react_1.default.createElement(ConfigurablePager_1.ConfigurablePager, { page: 1, pageSize: 10, totalPages: 10, pageSizes: [10, 13, 17], onChange: onChange }));
        user_event_1.default.click(react_2.screen.getByText('2'));
        await (0, __testHelpers__1.waitForReactUpdates)();
        expect(onChange).toHaveBeenCalled();
        expect(onChange).toHaveBeenCalledWith(2, 10);
    });
});
describe('pageReducer', () => {
    test('setPage', () => {
        const { page, pageSize } = (0, ConfigurablePager_1.pageReducer)({ page: 3, pageSize: 10 }, ConfigurablePager_1.pageActions.setPage(7));
        expect(page).toBe(7);
        expect(pageSize).toBe(10);
    });
    describe('setPageSize', () => {
        test('normal', () => {
            const { page, pageSize } = (0, ConfigurablePager_1.pageReducer)({ page: 8, pageSize: 10 }, ConfigurablePager_1.pageActions.setPageSize(25));
            // firstVisibleItemIndex = 70
            expect(page).toBe(3);
            expect(pageSize).toBe(25);
        });
        test('below boundary', () => {
            const { page, pageSize } = (0, ConfigurablePager_1.pageReducer)({ page: 10, pageSize: 11 }, ConfigurablePager_1.pageActions.setPageSize(25));
            // firstVisibleItemIndex = 99
            expect(page).toBe(4);
            expect(pageSize).toBe(25);
        });
        test('above boundary', () => {
            const { page, pageSize } = (0, ConfigurablePager_1.pageReducer)({ page: 2, pageSize: 26 }, ConfigurablePager_1.pageActions.setPageSize(25));
            // firstVisibleItemIndex = 26
            expect(page).toBe(2);
            expect(pageSize).toBe(25);
        });
        test("doesn't set page to 0", () => {
            const { page, pageSize } = (0, ConfigurablePager_1.pageReducer)({ page: 1, pageSize: 10 }, ConfigurablePager_1.pageActions.setPageSize(25));
            expect(page).toBe(1);
            expect(pageSize).toBe(25);
        });
    });
});
