"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Pager = void 0;
const react_1 = __importDefault(require("react"));
const LinkButton_1 = require("./LinkButton");
// Mark as disabled (rather than making it invisible) so the pager doesn't
// jump around
function PagerLink({ active, onClick, enabled, children }) {
    return (react_1.default.createElement("li", { className: `page-item ${active ? 'active' : ''} ${enabled ? '' : 'disabled'}` },
        react_1.default.createElement(LinkButton_1.LinkButton, { className: "page-link", tabIndex: enabled ? undefined : -1, onClick: onClick }, children)));
}
/**
 * A simple pagination control that does not allow setting the number of items on a page.
 *
 * These days, [[`ConfigurablePager`]] is generally preferred.
 */
exports.Pager = react_1.default.memo(({ page, totalPages, onPageChange, enabled = true, containerClassName = 'pagination-container', }) => {
    const firstPage = 1;
    const hasPrevious = page !== firstPage;
    const hasNext = page < totalPages;
    // Don't want to show too many pages if there are a lot
    const pagesToDisplay = 5; // odd number
    let pageNumbers = [page];
    let distance = 1;
    // add page number to the left and right until hit the pagesToDisplay
    // and/or run out of pages
    // eslint-disable-next-line no-constant-condition
    while (true) {
        const left = page - distance;
        const addLeft = left >= firstPage;
        if (addLeft)
            pageNumbers = [left].concat(pageNumbers);
        const right = page + distance;
        const addRight = right <= totalPages;
        if (addRight)
            pageNumbers.push(right);
        if (pageNumbers.length === pagesToDisplay || (!addLeft && !addRight)) {
            break;
        }
        distance += 1;
    }
    return (react_1.default.createElement("nav", { "aria-label": "Page navigation", className: containerClassName },
        react_1.default.createElement("ul", { className: "pagination" },
            react_1.default.createElement(PagerLink, { onClick: () => onPageChange(page - 1), key: "prev", enabled: enabled && hasPrevious },
                react_1.default.createElement("span", { "aria-hidden": "true" }, "\u00AB"),
                react_1.default.createElement("span", { className: "visually-hidden" }, "Previous")),
            pageNumbers.map((i) => (react_1.default.createElement(PagerLink, { onClick: () => onPageChange(i), active: page === i, key: i.toString(), enabled: enabled }, i))),
            react_1.default.createElement(PagerLink, { onClick: () => onPageChange(page + 1), key: "next", enabled: enabled && hasNext },
                react_1.default.createElement("span", { "aria-hidden": "true" }, "\u00BB"),
                react_1.default.createElement("span", { className: "visually-hidden" }, "Next")))));
});
