"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SavedMessage = void 0;
const free_solid_svg_icons_1 = require("@fortawesome/free-solid-svg-icons");
const react_fontawesome_1 = require("@fortawesome/react-fontawesome");
const react_1 = __importStar(require("react"));
/**
 * Shows a "✔ Saved" message next to your "Save changes" button to show that
 * user that the change went through. The message fades in and out.
 *
 * ```
 * const showSavedMessageRef = useRef(() => {})
 *
 * function saveChanges() {
 *     // call the API
 *
 *     showSavedMessageRef.current()
 * }
 *
 * return <div>
 *     ...
 *      <SavedMessage
 *          showSavedMessageRef={showSavedMessageRef}
 *          className="saved-message-me"
 *      />
 *     ...
 * </div>
 * ```
 */
function SavedMessage({ showSavedMessageRef, className, }) {
    const [show, setShow] = (0, react_1.useState)(false);
    const timerRef = (0, react_1.useRef)();
    function onSave() {
        setShow(true);
        clearTimeout(timerRef.current);
        timerRef.current = window.window.setTimeout(() => setShow(false), 1800);
    }
    (0, react_1.useEffect)(() => {
        showSavedMessageRef.current = onSave;
    });
    (0, react_1.useEffect)(() => () => {
        clearTimeout(timerRef.current);
    }, []);
    const classes = ['saved-message'];
    if (className)
        classes.push(className);
    return (react_1.default.createElement("div", { className: classes.join(' '), style: { opacity: show ? 1 : 0 } },
        react_1.default.createElement(react_fontawesome_1.FontAwesomeIcon, { icon: free_solid_svg_icons_1.faCheck }),
        " Saved"));
}
exports.SavedMessage = SavedMessage;
