"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTdLink = void 0;
const react_1 = __importDefault(require("react"));
const react_router_dom_1 = require("react-router-dom");
/**
 * Makes a table cell into a link.
 *
 * `TdLink` has styles that are required for it to work correctly.
 *
 * ```
 * <table className="table table-hover table-td-link">
 *     <tbody>
 *         {products.map(p => {
 *             const Td = getTdLink('/product/detail/' + p.id)
 *
 *             return (
 *                 <tr key={p.id}>
 *                     <Td>{p.id}</Td>
 *                     <Td>{p.name}</Td>
 *                     <Td>{p.stock}</Td>
 *                 </tr>
 *             )
 *          })}
 *     </tbody>
 * </table>
 * ```
 */
function getTdLink(to, tdProps) {
    function TdLink({ children, className, ...otherProps }) {
        const classes = ['td-link'];
        if (className)
            classes.push(className);
        return (react_1.default.createElement("td", { ...tdProps },
            react_1.default.createElement(react_router_dom_1.Link, { to: to, className: classes.join(' '), ...otherProps }, children)));
    }
    return TdLink;
}
exports.getTdLink = getTdLink;
