"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfirmDialog = exports.confirm = void 0;
const react_1 = __importStar(require("react"));
const react_confirm_1 = require("react-confirm");
const lodash_1 = require("lodash");
const dialog_1 = require("./dialog");
const defaultOptions = {
    title: 'Confirm',
};
function ConfirmDialogPresentation({ show, confirmation, loading = false, isStandalone = false, options, closeRef: propsCloseRef, ...otherProps }) {
    const privateCloseRef = (0, react_1.useRef)(() => { });
    const closeRef = propsCloseRef !== null && propsCloseRef !== void 0 ? propsCloseRef : privateCloseRef;
    const proceedCalledRef = (0, react_1.useRef)(false);
    let proceed;
    let onClose;
    if (isStandalone) {
        proceed = otherProps.proceed;
        onClose = () => {
            if (!proceedCalledRef.current)
                otherProps.cancel();
        };
    }
    else {
        proceed = () => {
            proceedCalledRef.current = true;
            closeRef.current();
        };
        onClose = () => {
            if (proceedCalledRef.current) {
                otherProps.proceed();
            }
            else {
                // important: we want to be able to await our confirm function, so call cancel
                // instead of dismiss so that closing the dialog results in the promise being rejected.
                // react-confirm does not resolve or reject if you call dismiss()
                otherProps.cancel();
            }
        };
    }
    const { cancelButtonText, actionButtonText, actionButtonClass, modalClass, title } = (0, lodash_1.defaults)({ ...options }, defaultOptions);
    if (!show)
        return null;
    return (react_1.default.createElement(dialog_1.ActionDialog, { title: title, onClose: onClose, closeRef: closeRef, actionButtonText: actionButtonText, actionButtonClass: actionButtonClass, cancelButtonText: cancelButtonText, action: proceed, actionInProgress: loading, focusFirst: true, modalClass: modalClass }, confirmation));
}
// confirmable HOC pass props `show`, `dismiss`, `cancel` and `proceed` to your component
const ConfirmableDialog = (0, react_confirm_1.confirmable)(ConfirmDialogPresentation);
const confirm0 = (0, react_confirm_1.createConfirmation)(ConfirmableDialog);
/** Imperative-style confirm dialog backed by `react-confirm`. */
function confirm(confirmation, options) {
    return confirm0({ options, confirmation }).then(() => undefined); // ignore return value
}
exports.confirm = confirm;
/** Standalone confirm dialog that does not use `react-confirm`. */
function ConfirmDialog({ confirmation, proceed, cancel, actionButtonText, actionButtonClass, loading = false, title, cancelButtonText, closeRef, modalClass, }) {
    const options = {
        title,
        actionButtonText,
        actionButtonClass,
        cancelButtonText,
        modalClass,
    };
    return (react_1.default.createElement(ConfirmDialogPresentation, { isStandalone: true, confirmation: confirmation, proceed: proceed, cancel: cancel, dismiss: () => {
            throw new Error('ConfirmDialogPresentation called dismiss(). This should never happen!');
        }, show: true, loading: loading, options: options, closeRef: closeRef }));
}
exports.ConfirmDialog = ConfirmDialog;
