"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TabLayout = void 0;
const react_1 = __importDefault(require("react"));
const LinkButton_1 = require("../LinkButton");
function TabLink(props) {
    const { tab, current, onClick } = props;
    const anchorClasses = ['nav-link'];
    if (current === tab[0])
        anchorClasses.push('active');
    if (tab.length === 3) {
        const tabOptions = tab[2];
        if (tabOptions.className)
            anchorClasses.push(tabOptions.className);
    }
    return (react_1.default.createElement("li", { className: "nav-item" },
        react_1.default.createElement(LinkButton_1.LinkButton, { className: anchorClasses.join(' '), onClick: onClick }, tab[1])));
}
/**
 * A presentational component for building user interfaces with tabs.
 *
 * Usually you want to use [[`TabManager`]] which builds on top of `TabLayout`.
 */
function TabLayout({ tabs, children, tab, onTabClick, tabContentRef, tabContentStyle, className, }) {
    const navClasses = ['nav', 'nav-tabs'];
    const classes = ['tab-layout'];
    if (className)
        classes.push(className);
    return (react_1.default.createElement("div", { className: classes.join(' ') },
        react_1.default.createElement("ul", { className: navClasses.join(' ') }, tabs.map((t) => (react_1.default.createElement(TabLink, { key: t[0], tab: t, current: tab, onClick: () => onTabClick(t[0]) })))),
        react_1.default.createElement("div", { className: "tab-content", ref: tabContentRef, style: tabContentStyle }, children)));
}
exports.TabLayout = TabLayout;
