"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TabManager = exports.getTabFromLocation = void 0;
const react_1 = __importStar(require("react"));
const react_router_dom_1 = require("react-router-dom");
const lodash_1 = require("lodash");
const TabLayout_1 = require("./TabLayout");
const TabContentLoading_1 = require("./TabContentLoading");
const ReadyContext_1 = require("../../routing/ReadyContext");
const defaultUrlParamName = 'tab';
/** Determines the current tab from the `Location` object. */
function getTabFromLocation(tabs, location, options) {
    if (tabs.length === 0)
        throw new Error('tabs array cannot be empty.');
    const { defaultTabName, urlParamName } = (0, lodash_1.defaults)(options, {
        urlParamName: defaultUrlParamName,
    });
    const searchParams = new URLSearchParams(location.search);
    const tabParam = searchParams.get(urlParamName);
    if (tabParam && tabs.some((t) => t[0] === tabParam))
        return tabParam;
    if (defaultTabName)
        return defaultTabName;
    return tabs[0][0];
}
exports.getTabFromLocation = getTabFromLocation;
// When the user switches to a tab that needs to load first, keep the height
// of the tab-content the same until the new tab finishes loading to avoid
// jarring changes in height
function useSmoothTabTransition(renderTabs, tab) {
    const tabContentRef = (0, react_1.useRef)(null);
    const [explicitTabContentHeight, setExplicitTabContentHeight] = (0, react_1.useState)();
    const [setHeightTo, setSetHeightTo] = (0, react_1.useState)();
    // When a new tab is about to mount, get the height of the tabContent
    // BEFORE the tabs actually switch
    function newTabWillMount() {
        if (tabContentRef.current) {
            const height = tabContentRef.current.offsetHeight;
            if (typeof height === 'number')
                setSetHeightTo(height);
        }
    }
    // Explicitly set the tabContent height immediately after the new tab becomes
    // visible. useLayoutEffect is essential here because we want the effect to
    // run *before the browser paints*.
    (0, react_1.useLayoutEffect)(() => {
        if (typeof setHeightTo === 'number') {
            setExplicitTabContentHeight(setHeightTo);
            setSetHeightTo(undefined);
        }
    }, [setHeightTo]);
    const currentRenderTab = renderTabs.find((rt) => rt[0] === tab);
    // Set explicit height to undefined when new tab becomes ready
    (0, react_1.useLayoutEffect)(() => {
        if (typeof explicitTabContentHeight === 'number') {
            if (currentRenderTab && currentRenderTab[1]) {
                setExplicitTabContentHeight(undefined);
            }
        }
    }, [explicitTabContentHeight, currentRenderTab]);
    return { tabContentRef, explicitTabContentHeight, newTabWillMount };
}
/**
 * A high-level component for creating user interfaces with tabs.
 *
 * - It stores the current tab name as a URL search params.
 * - It doesn't mount the a tab until the user actually visits that tab. (You can disable this with by setting `mountAllTabs` to true.)
 * - It shows a loading indicator if a tab needs to load data before it can render content.
 */
function TabManager({ tabs, children, defaultTabName, renderLoadingIndicator, mountAllTabs = false, urlParamName = defaultUrlParamName, displaySingleTab = true, className, }) {
    const navigate = (0, react_router_dom_1.useNavigate)();
    const { location } = (0, ReadyContext_1.useReadyCore)();
    let tab = '';
    if (tabs.length > 0) {
        tab = getTabFromLocation(tabs, location, { defaultTabName, urlParamName });
    }
    const [mountedTabs, setMountedTabs] = (0, react_1.useState)([tab]);
    const { tabContentRef, explicitTabContentHeight, newTabWillMount } = useSmoothTabTransition(children, tab);
    (0, react_1.useEffect)(() => {
        if (mountAllTabs)
            return;
        if (!mountedTabs.includes(tab)) {
            setMountedTabs((mountedTabs) => [...mountedTabs, tab]);
        }
    }, [mountedTabs, tab, mountAllTabs]);
    function onTabClick(tabName) {
        if (!mountedTabs.includes(tabName))
            newTabWillMount();
        const searchParams = new URLSearchParams(location.search);
        searchParams.set(urlParamName, tabName);
        navigate({
            ...location,
            search: searchParams.toString(),
        }, { replace: true });
    }
    function renderTab(theRenderTab) {
        const [thisTabName, ready, reactNode] = theRenderTab;
        if (!mountAllTabs && !mountedTabs.includes(thisTabName))
            return null;
        return (react_1.default.createElement("div", { style: {
                display: tab === thisTabName ? undefined : 'none',
            }, className: !ready ? 'render-tab-loading' : undefined, key: thisTabName },
            !ready && (react_1.default.createElement(TabContentLoading_1.TabContentLoading, { renderLoadingIndicator: renderLoadingIndicator })),
            react_1.default.createElement("div", { hidden: !ready }, reactNode)));
    }
    if (tabs.length === 1 && !displaySingleTab) {
        if (!children || children.length === 0)
            return null;
        // Display contents without a tab or border
        return renderTab(children[0]);
    }
    return (react_1.default.createElement(TabLayout_1.TabLayout, { tabs: tabs, tab: tab, onTabClick: onTabClick, tabContentRef: tabContentRef, tabContentStyle: typeof explicitTabContentHeight === 'number'
            ? { height: explicitTabContentHeight }
            : undefined, className: className }, children && children.map(renderTab)));
}
exports.TabManager = TabManager;
