"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileValidators = exports.FileInput = void 0;
const react_1 = __importDefault(require("react"));
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const validation_1 = require("../validation");
/**
 * A file upload control that can be made a required field.
 */
function FileInput({ id, accept, enabled, inputAttributes, showValidation, name, ...props }) {
    const { value, onChange } = (0, iti_react_core_1.useControlledValue)({
        value: props.value,
        onChange: props.onChange,
        defaultValue: props.defaultValue,
        fallbackValue: null,
    });
    const validatorOutput = (0, iti_react_core_1.useValidation)({
        value,
        name,
        onValidChange: props.onValidChange,
        validators: props.validators,
        validationKey: props.validationKey,
        asyncValidator: props.asyncValidator,
        onAsyncError: props.onAsyncError,
        formLevelValidatorOutput: props.formLevelValidatorOutput,
    });
    return (react_1.default.createElement(validation_1.ValidationFeedback, { validatorOutput: validatorOutput, showValidation: showValidation },
        react_1.default.createElement("input", { id: id, className: "form-control", type: "file", name: name, accept: accept, onChange: (e) => {
                var _a;
                const files = (_a = e.target) === null || _a === void 0 ? void 0 : _a.files;
                if (files && files[0]) {
                    onChange(files[0]);
                }
                else {
                    onChange(null);
                }
            } })));
}
exports.FileInput = FileInput;
function required() {
    return (value) => {
        if (!value)
            return iti_react_core_1.Validators.required()('');
        return undefined;
    };
}
/** For use with [[`FileInput`]]. */
exports.FileValidators = { required };
