"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BooleanRadioValidators = exports.BooleanRadioInput = void 0;
const react_1 = __importDefault(require("react"));
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const RadioInput_1 = require("./RadioInput");
function convertValue(value) {
    if (typeof value === 'undefined')
        return undefined;
    if (value === null)
        return null;
    return value.toString();
}
function convertValidator(validator) {
    return (value) => {
        const booleanValue = value !== null ? value === true.toString() : null;
        return validator(booleanValue);
    };
}
function convertAsyncValidator(validator) {
    return (value) => {
        const booleanValue = value !== null ? value === true.toString() : null;
        return validator(booleanValue);
    };
}
/**
 * Wrapper around [[`RadioInput`]] for when there are only two options, true and false.
 */
function BooleanRadioInput({ trueFirst = true, value, onChange, defaultValue, validators, labels = { false: 'No', true: 'Yes' }, asyncValidator, ...passThroughProps }) {
    const options = [
        { value: true.toString(), label: labels.true },
        { value: false.toString(), label: labels.false },
    ];
    if (!trueFirst)
        options.reverse();
    return (react_1.default.createElement(RadioInput_1.RadioInput, { options: options, value: convertValue(value), defaultValue: convertValue(defaultValue), onChange: (value) => {
            if (onChange)
                onChange(value === true.toString());
        }, validators: validators.map(convertValidator), asyncValidator: asyncValidator ? convertAsyncValidator(asyncValidator) : undefined, ...passThroughProps }));
}
exports.BooleanRadioInput = BooleanRadioInput;
//
//
//
function required() {
    return (value) => {
        if (value === null)
            return iti_react_core_1.Validators.required()('');
        return undefined;
    };
}
exports.BooleanRadioValidators = {
    required,
};
