"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValidationClass = exports.ValidationFeedback = exports.useDebouncedAsyncValidationPending = void 0;
const react_1 = __importStar(require("react"));
const use_debounce_1 = require("use-debounce");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const ItiReactContext_1 = require("../ItiReactContext");
/**
 * Used to show a loading indicator when async validation is progress. Uses debouncing
 * so the loading indicator is never displayed if the async validation completes quickly.
 */
function useDebouncedAsyncValidationPending(propsPending) {
    const [pending, setPending] = (0, react_1.useState)(false);
    const setPendingDebounced = (0, use_debounce_1.useDebouncedCallback)(setPending, 1000);
    (0, react_1.useEffect)(() => {
        if (propsPending) {
            setPendingDebounced(true);
        }
        else {
            setPendingDebounced.cancel();
            setPending(false);
        }
    }, [propsPending, setPendingDebounced]);
    return pending;
}
exports.useDebouncedAsyncValidationPending = useDebouncedAsyncValidationPending;
/**
 * Displays validation feedback below an input. Used by `ValidatedInput`, .etc.
 *
 * You usually won't use this directly unless creating your own input component.
 */
function ValidationFeedback({ validatorOutput, showValidation, children, renderLoadingIndicator, }) {
    const contextRenderLoadingIndicator = (0, react_1.useContext)(ItiReactContext_1.ItiReactContext).renderLoadingIndicator;
    renderLoadingIndicator = renderLoadingIndicator !== null && renderLoadingIndicator !== void 0 ? renderLoadingIndicator : contextRenderLoadingIndicator;
    const debouncedAsyncValidationPending = useDebouncedAsyncValidationPending(validatorOutput === iti_react_core_1.ASYNC_VALIDATION_PENDING);
    let feedback;
    if (showValidation) {
        if (validatorOutput === iti_react_core_1.ASYNC_VALIDATION_PENDING) {
            if (debouncedAsyncValidationPending) {
                feedback = (react_1.default.createElement("div", { className: "pending-feedback" },
                    renderLoadingIndicator(),
                    " Validating..."));
            }
        }
        else if (validatorOutput &&
            validatorOutput !== iti_react_core_1.INVALID_NO_FEEDBACK &&
            validatorOutput !== iti_react_core_1.ASYNC_VALIDATION_DEBOUNCE_PENDING) {
            feedback = react_1.default.createElement("div", { className: "invalid-feedback" }, validatorOutput);
        }
    }
    return (react_1.default.createElement("div", { className: "validated-input" },
        children,
        feedback));
}
exports.ValidationFeedback = ValidationFeedback;
/**
 * Returns a Bootstrap validation class depending on `valid` and `showValidation`.
 */
function getValidationClass(valid, showValidation) {
    if (showValidation) {
        if (valid)
            return 'is-valid';
        return 'is-invalid';
    }
    return '';
}
exports.getValidationClass = getValidationClass;
