"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_2 = require("@testing-library/react");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const __testHelpers__1 = require("../__testHelpers__");
const ValidationFeedback_1 = require("./ValidationFeedback");
it('does not render feedback if valid', () => {
    (0, react_2.render)(react_1.default.createElement(__testHelpers__1.DefaultProviders, null,
        react_1.default.createElement(ValidationFeedback_1.ValidationFeedback, { validatorOutput: undefined, showValidation: true })));
    expect(document.querySelector('.validated-input')).toBeEmptyDOMElement();
});
it('does not render feedback if validatorOutput=INVALID_NO_FEEDBACK', () => {
    (0, react_2.render)(react_1.default.createElement(__testHelpers__1.DefaultProviders, null,
        react_1.default.createElement(ValidationFeedback_1.ValidationFeedback, { validatorOutput: iti_react_core_1.INVALID_NO_FEEDBACK, showValidation: true })));
    expect(document.querySelector('.validated-input')).toBeEmptyDOMElement();
});
it('renders feedback if invalid', () => {
    (0, react_2.render)(react_1.default.createElement(__testHelpers__1.DefaultProviders, null,
        react_1.default.createElement(ValidationFeedback_1.ValidationFeedback, { validatorOutput: "myFeedback", showValidation: true })));
    const invalidFeedback = document.querySelector('.invalid-feedback');
    expect(invalidFeedback).toBeVisible();
    expect(invalidFeedback).toHaveTextContent('myFeedback');
    expect(document.querySelector('.pending-feedback')).toBeNull();
});
it('does not show loading indicator if validatorOutput=ASYNC_VALIDATION_DEBOUNCE_PENDING', async () => {
    (0, react_2.render)(react_1.default.createElement(__testHelpers__1.DefaultProviders, null,
        react_1.default.createElement(ValidationFeedback_1.ValidationFeedback, { validatorOutput: iti_react_core_1.ASYNC_VALIDATION_DEBOUNCE_PENDING, showValidation: true })));
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    expect(document.querySelector('.pending-feedback')).toBeNull();
    await (0, __testHelpers__1.waitForReactUpdates)();
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    expect(document.querySelector('.pending-feedback')).toBeNull();
});
it('shows loading indicator after a delay if validatorOutput=ASYNC_VALIDATION_PENDING', async () => {
    const { rerender } = (0, react_2.render)(react_1.default.createElement(__testHelpers__1.DefaultProviders, null,
        react_1.default.createElement(ValidationFeedback_1.ValidationFeedback, { validatorOutput: iti_react_core_1.ASYNC_VALIDATION_PENDING, showValidation: true })));
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    expect(document.querySelector('.pending-feedback')).toBeNull();
    await (0, __testHelpers__1.waitForReactUpdates)();
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    const pendingFeedback = document.querySelector('.pending-feedback');
    expect(pendingFeedback).toBeVisible();
    expect(pendingFeedback).toHaveTextContent(/LOADING INDICATOR/);
    expect(pendingFeedback).toHaveTextContent(/Validating\.\.\./);
    rerender(react_1.default.createElement(__testHelpers__1.DefaultProviders, null,
        react_1.default.createElement(ValidationFeedback_1.ValidationFeedback, { validatorOutput: undefined, showValidation: true })));
    // Pending feedback should be removed immediately
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    expect(document.querySelector('.pending-feedback')).toBeNull();
});
